aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/hook/finder.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2013-09-27 10:47:10 +0200
committerMarc Alexander <admin@m-a-styles.de>2013-09-27 10:47:10 +0200
commit663b4b2eb74e8edb076c962662ff5124e94353ea (patch)
tree0ff449c776397b2b66fc7d567f93bbb7d62ea2e3 /phpBB/phpbb/hook/finder.php
parent01512104b5823d15eed64d362b41b9594f870f0c (diff)
parent8db820be634cfce0fdb079fdbaee2c49661a7870 (diff)
downloadforums-663b4b2eb74e8edb076c962662ff5124e94353ea.tar
forums-663b4b2eb74e8edb076c962662ff5124e94353ea.tar.gz
forums-663b4b2eb74e8edb076c962662ff5124e94353ea.tar.bz2
forums-663b4b2eb74e8edb076c962662ff5124e94353ea.tar.xz
forums-663b4b2eb74e8edb076c962662ff5124e94353ea.zip
Merge branch 'develop' of https://github.com/phpbb/phpbb3 into feature/passwords
Conflicts: phpBB/develop/create_schema_files.php
Diffstat (limited to 'phpBB/phpbb/hook/finder.php')
-rw-r--r--phpBB/phpbb/hook/finder.php8
1 files changed, 5 insertions, 3 deletions
diff --git a/phpBB/phpbb/hook/finder.php b/phpBB/phpbb/hook/finder.php
index 7b0412f733..d5eb1f8186 100644
--- a/phpBB/phpbb/hook/finder.php
+++ b/phpBB/phpbb/hook/finder.php
@@ -7,6 +7,8 @@
*
*/
+namespace phpbb\hook;
+
/**
* @ignore
*/
@@ -20,7 +22,7 @@ if (!defined('IN_PHPBB'))
*
* @package phpBB3
*/
-class phpbb_hook_finder
+class finder
{
protected $phpbb_root_path;
protected $cache;
@@ -31,9 +33,9 @@ class phpbb_hook_finder
*
* @param string $phpbb_root_path Path to the phpbb root directory
* @param string $php_ext php file extension
* @param phpbb_cache_driver_interface $cache A cache instance or null
*/
- public function __construct($phpbb_root_path, $php_ext, phpbb_cache_driver_interface $cache = null)
+ public function __construct($phpbb_root_path, $php_ext, \phpbb\cache\driver\driver_interface $cache = null)
{
$this->phpbb_root_path = $phpbb_root_path;
$this->cache = $cache;
@@ -31,9 +33,9 @@ class phpbb_hook_finder
* @param string $phpbb_root_path Path to the phpbb root directory
* @param string $php_ext php file extension
- * @param phpbb_cache_driver_interface $cache A cache instance or null
+ * @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
*/